import { NSVElement, registerElement } from 'react-nativescript';
import { Color, Image, Label } from '@nativescript/core';
import { warn } from 'react-nativescript/dist/shared/Logger';
import { TabContentItem } from '../tab-content-item';
import { TabStrip } from '../tab-strip';
import { TabStripItem } from '../tab-strip-item';
let installed = false;
export function registerTabNavigationBase(opts = {}) {
    const { enableDebugLogging = false } = opts;
    if (installed) {
        return;
    }
    registerElement('tabStrip', () => TabStrip, {
        nodeOps: {
            insert(child, parent, atIndex) {
                const tabStrip = parent.nativeView;
                if (child.nodeRole === 'items') {
                    if (child.nativeView instanceof TabStripItem === false) {
                        if (enableDebugLogging) {
                            warn(`Unable to add child "${child.nativeView.constructor.name}" to the items of <tabStrip> as it is not an instance of TabStripItem.`);
                        }
                        return;
                    }
                    const items = tabStrip.items || [];
                    if (typeof atIndex === 'undefined' || atIndex === items.length) {
                        tabStrip._addChildFromBuilder('items', child.nativeView);
                    }
                    else {
                        const itemsClone = items.slice();
                        itemsClone.splice(atIndex, 0, child.nativeView);
                        tabStrip.items = itemsClone;
                    }
                }
                else if (child.nodeRole === 'item') {
                    if (enableDebugLogging) {
                        warn(`Unable to add child "${child.nativeView.constructor.name}" to <tabStrip> as it had the nodeRole "item"; please correct it to "items".`);
                    }
                }
                else {
                    if (enableDebugLogging) {
                        warn(`Unable to add child "${child.nativeView.constructor.name}" to <tabStrip> as it does not have a nodeRole specified; ` +
                            'please set a nodeRole of "tabStrip", or "items".');
                    }
                }
            },
            remove(child, parent) {
                const tabStrip = parent.nativeView;
                if (child.nodeRole === 'items') {
                    tabStrip.items = (tabStrip.items || []).filter((i) => i !== child.nativeView);
                }
                else if (child.nodeRole === 'item') {
                    if (enableDebugLogging) {
                        warn(`Unable to remove child "${child.nativeView.constructor.name}" from <tabStrip> as it had the nodeRole "item"; please correct it to "items".`);
                    }
                }
                else {
                    if (enableDebugLogging) {
                        warn(`Unable to remove child "${child.nativeView.constructor.name}" from <tabStrip> as it does not have a nodeRole specified; ` +
                            'please set a nodeRole of "tabStrip", or "items"');
                    }
                }
            }
        }
    });
    registerElement('tabStripItem', () => TabStripItem, {
        nodeOps: {
            insert(child, parent, atIndex) {
                const tabStripItem = parent.nativeView;
                if (child.nodeRole === 'label') {
                    if (child.nativeView instanceof Label === false) {
                        if (enableDebugLogging) {
                            warn(`Unable to add child "${child.nativeView.constructor.name}" to the items of <tabStripItem> as it is not an instance of Label.`);
                        }
                        return;
                    }
                    tabStripItem.label = child.nativeView;
                }
                else if (child.nodeRole === 'image') {
                    if (child.nativeView instanceof Image === false) {
                        if (enableDebugLogging) {
                            warn(`Unable to add child "${child.nativeView.constructor.name}" to the items of <tabStripItem> as it is not an instance of Image.`);
                        }
                        return;
                    }
                    tabStripItem.image = child.nativeView;
                }
                else {
                    if (enableDebugLogging) {
                        warn(`Unable to add child "${child.nativeView.constructor.name}" to <tabStripItem> as it does not have a nodeRole specified; ` +
                            'please set a nodeRole of "label", or "image".');
                    }
                }
            },
            remove(child, parent) {
                const tabStripItem = parent.nativeView;
                if (child.nodeRole === 'label') {
                    tabStripItem.label = null;
                }
                else if (child.nodeRole === 'image') {
                    tabStripItem.image = null;
                }
                else {
                    if (enableDebugLogging) {
                        warn(`Unable to remove child "${child.nativeView.constructor.name}" from <tabStripItem> as it does not have a nodeRole specified; ` +
                            'please set a nodeRole of "label", or "image"');
                    }
                }
            }
        }
    });
    registerElement('tabContentItem', () => TabContentItem, { viewFlags: 2 });
    installed = true;
}
//# sourceMappingURL=index.js.map