import { CoercibleProperty, Color, Property, View, ViewBase, booleanConverter } from '@nativescript/core';
import { TabNavigationBase as TabNavigationBaseDefinition } from '.';
import { TabContentItem } from '../tab-content-item';
import { TabStrip } from '../tab-strip';
import { TabStripItem } from '../tab-strip-item';
export class TabNavigationBase extends View {
    _addArrayFromBuilder(name, value) {
        if (name === 'items') {
            this.items = value;
        }
    }
    _addChildFromBuilder(name, value) {
        if (value instanceof TabContentItem) {
            if (!this.items) {
                this.items = new Array();
            }
            this.items.push(value);
            this._addView(value);
        }
        else if (value instanceof TabStrip) {
            this.tabStrip = value;
        }
    }
    get _selectedView() {
        const selectedIndex = this.selectedIndex;
        return selectedIndex > -1 ? this.items[selectedIndex].content : null;
    }
    get _childrenCount() {
        const items = this.items;
        return items ? items.length : 0;
    }
    eachChild(callback) {
        const items = this.items;
        if (items) {
            items.forEach((item, i) => {
                callback(item);
            });
        }
        const tabStrip = this.tabStrip;
        if (tabStrip) {
            callback(tabStrip);
        }
    }
    eachChildView(callback) {
        const items = this.items;
        if (items) {
            items.forEach((item, i) => {
                callback(item.content);
            });
        }
    }
    onItemsChanged(oldItems, newItems) {
        if (oldItems) {
            oldItems.forEach((item) => {
                if (newItems.indexOf(item) === -1) {
                    this._removeView(item);
                }
            });
        }
        if (newItems) {
            newItems.forEach((item) => {
                if (!item.content) {
                    throw new Error('TabContentItem must have a content (view).');
                }
                if (oldItems.indexOf(item) === -1) {
                    this._addView(item);
                }
            });
        }
    }
    onTabStripChanged(oldTabStrip, newTabStrip) {
        if (oldTabStrip && oldTabStrip.parent) {
            this._removeView(oldTabStrip);
        }
        if (newTabStrip) {
            this._addView(newTabStrip);
        }
    }
    onSelectedIndexChanged(oldIndex, newIndex) {
        const items = this.items;
        if (items[oldIndex]) {
            items[oldIndex].content.notify({
                eventName: TabNavigationBase.unselectedEvent,
                object: this
            });
        }
        if (items[newIndex]) {
            items[newIndex].content.notify({
                eventName: TabNavigationBase.selectedEvent,
                object: this
            });
        }
        this.notify({
            eventName: TabNavigationBase.selectedIndexChangedEvent,
            object: this,
            oldIndex,
            newIndex
        });
    }
    getTabBarBackgroundColor() {
        return null;
    }
    getTabBarBackgroundArgbColor() {
        const colorDrawable = this.getTabBarBackgroundColor();
        return colorDrawable && colorDrawable.getColor && colorDrawable.getColor();
    }
    setTabBarBackgroundColor(value) {
    }
    getTabBarFontInternal() {
        return null;
    }
    setTabBarFontInternal(value) {
    }
    getTabBarTextTransform() {
        return null;
    }
    setTabBarTextTransform(value) {
    }
    getTabBarHighlightColor() {
    }
    setTabBarHighlightColor(value) {
    }
    getTabBarSelectedItemColor() {
        return null;
    }
    setTabBarSelectedItemColor(value) {
    }
    getTabBarUnSelectedItemColor() {
        return null;
    }
    setTabBarUnSelectedItemColor(value) {
    }
    getTabBarColor() {
        return null;
    }
    setTabBarColor(value) {
    }
    setTabBarItemTitle(tabStripItem, value) {
    }
    getTabBarItemBackgroundColor(tabStripItem) {
        return null;
    }
    setTabBarItemBackgroundColor(tabStripItem, value) {
    }
    getTabBarItemColor(tabStripItem) {
        return null;
    }
    setTabBarItemColor(tabStripItem, value) {
    }
    setTabBarIconColor(tabStripItem, value) {
    }
    setTabBarIconSource(tabStripItem, value) {
    }
    getTabBarItemFontSize(tabStripItem) {
        return null;
    }
    setTabBarItemFontSize(tabStripItem, value) {
    }
    getTabBarItemFontInternal(tabStripItem) {
        return null;
    }
    setTabBarItemFontInternal(tabStripItem, value) {
    }
    getTabBarItemTextTransform(tabStripItem) {
        return null;
    }
    setTabBarItemTextTransform(tabStripItem, value) {
    }
    setTabBarRippleColor(value) {
    }
    getTabBarRippleColor() {
        return null;
    }
    _getParentFragmentManagerFromFragment(fragment) {
        if (!fragment) {
            return null;
        }
        try {
            return fragment.getParentFragmentManager();
        }
        catch (e) {
            return null;
        }
    }
}
TabNavigationBase.selectedIndexChangedEvent = 'selectedIndexChanged';
TabNavigationBase.selectedEvent = 'selected';
TabNavigationBase.unselectedEvent = 'unselected';
const MIN_ICON_SIZE = 24;
const MAX_ICON_WIDTH = 31;
const MAX_ICON_HEIGHT = 28;
export function getIconSpecSize(size) {
    const inWidth = size.width;
    const inHeight = size.height;
    let outWidth = 0;
    let outHeight = 0;
    if (inWidth < inHeight) {
        outWidth = MIN_ICON_SIZE;
        outHeight = (inHeight * MIN_ICON_SIZE) / inWidth;
        if (outHeight > MAX_ICON_HEIGHT) {
            outHeight = MAX_ICON_HEIGHT;
            outWidth = (inWidth * MAX_ICON_HEIGHT) / inHeight;
        }
    }
    else {
        outHeight = MIN_ICON_SIZE;
        outWidth = (inWidth * MIN_ICON_SIZE) / inHeight;
        if (outWidth > MAX_ICON_WIDTH) {
            outWidth = MAX_ICON_WIDTH;
            outHeight = (inHeight * MAX_ICON_WIDTH) / inWidth;
        }
    }
    return { width: outWidth, height: outHeight };
}
export const selectedIndexProperty = new CoercibleProperty({
    name: 'selectedIndex',
    defaultValue: -1,
    affectsLayout: global.isIOS,
    valueChanged: (target, oldValue, newValue) => {
        target.onSelectedIndexChanged(oldValue, newValue);
    },
    coerceValue: (target, value) => {
        const items = target.items;
        if (items) {
            const max = items.length - 1;
            if (value < 0) {
                value = 0;
            }
            if (value > max) {
                value = max;
            }
        }
        else {
            value = -1;
        }
        return value;
    },
    valueConverter: (v) => parseInt(v, 10)
});
selectedIndexProperty.register(TabNavigationBase);
export const _tabs = new Array();
export const itemsProperty = new Property({
    name: 'items',
    valueChanged: (target, oldValue, newValue) => {
        target.onItemsChanged(oldValue, newValue);
    }
});
itemsProperty.register(TabNavigationBase);
export const tabStripProperty = new Property({
    name: 'tabStrip',
    valueChanged: (target, oldValue, newValue) => {
        target.onTabStripChanged(oldValue, newValue);
    }
});
tabStripProperty.register(TabNavigationBase);
export const unloadOnTabChangeProperty = new Property({
    name: 'unloadOnTabChange',
    defaultValue: true,
    valueConverter: booleanConverter
});
unloadOnTabChangeProperty.register(TabNavigationBase);
//# sourceMappingURL=index.js.map